@@ -166,6 +166,7 @@ print_api_call <- function(url) {
 #' @param group A column in the dataset that identifies salient groups within which dots should be generated.  For a long-form tidycensus dataset, this will typically be the \code{"variable"} column or some derivative of it. The output dataset will be randomly shuffled to prevent "stacking" of groups in downstream dot-density maps.
 #' @param erase_water If \code{TRUE}, calls \code{tigris::erase_water()} to remove water areas from the polygons prior to generating dots, allowing for dasymetric dot placement. This option is recommended if your location includes significant water area. If using this option, it is recommended that you first transform your data to a projected coordinate reference system using \code{sf::st_transform()} to improve performance. This argument only works for data in the United States.
 #' @param area_threshold The area percentile threshold to be used when erasing water; ranges from 0 (all water area included) to 1 (no water area included)
+#' @param water_year The year of the TIGER/Line water area shapefiles to use if erasing water. Defaults to 2020; ignore if not using the \code{erase_water} feature.
 #'
 #' @return The original dataset but of geometry type \code{POINT}, with the number of point features corresponding to the given value:dot ratio for a given group.
 #' @export
@@ -221,7 +222,8 @@ as_dot_density <- function(
     values_per_dot,
     group = NULL,
     erase_water = FALSE,
-    area_threshold = NULL
+    area_threshold = NULL,
+    water_year = 2020
 ) {
 
   # Ensure that terra package is installed
@@ -237,7 +239,8 @@ as_dot_density <- function(
     }
 
     input_data <- tigris::erase_water(input_data,
-                                      area_threshold = area_threshold)
+                                      area_threshold = area_threshold,
+                                      year = water_year)
   } else {
     if (!is.null(area_threshold)) {
       message("`area_threshold` is to be used when erasing water from input polygons; ignoring as `erase_water` is currently `FALSE`.")
